---
name: Feature request
about: Tell us about something you'd like `crabnet` to support. Not for asking general questions - see below.
title: ''
labels: enhancement
assignees: sgbaird
---
<!--Below, please include details of the feature you would like to see and why you would like to see it/the use case.-->
